pub struct KeyId(/* private fields */);Expand description
A key id is a unique identifier for a single key. There is a 1:1 mapping between key ID and key bytes, so something like a user key rotation is replacing the key with ID A with a new key with ID B.
Implementations
Sourceimpl KeyId
Fixed length identifiers for keys.
These are intended to be unique and constant per-key.
impl KeyId
Fixed length identifiers for keys. These are intended to be unique and constant per-key.
Currently these are randomly generated 16 byte identifiers, which is considered safe to randomly generate with vanishingly small collision chance. However, the generation of IDs is an internal concern and may change in the future.