BitwardenLegacyKeyBytes

Type Alias BitwardenLegacyKeyBytes 

pub type BitwardenLegacyKeyBytes = Bytes<BitwardenLegacyKeyContentFormat>;
BitwardenLegacyKeyBytes is a type alias for Bytes with BitwardenLegacyKeyContentFormat. This is used for the legacy format for symmetric keys. A description of the format is available in the ContentFormat::BitwardenLegacyKey documentation.

Aliased Type

pub struct BitwardenLegacyKeyBytes { /* private fields */ }