pub enum SignatureAlgorithm {
Ed25519,
MlDsa44,
}Expand description
The type of key / signature scheme used for signing and verifying.
Variants
Ed25519
Ed25519 is the modern, secure recommended option for digital signatures on eliptic curves, safe under the assumption that an attacker does not have access to a large-scale quantum computer.
MlDsa44
ML-DSA-44 is the NIST post-quantum digital signature standard (FIPS 204), security category 2.
Implementations
Sourceimpl SignatureAlgorithm
impl SignatureAlgorithm
Sourcepub fn default_algorithm() -> Self
pub fn default_algorithm() -> Self
Returns the currently accepted safe algorithm for new keys.