DataEnvelope

Struct DataEnvelope 

pub struct DataEnvelope { /* private fields */ }
DataEnvelope allows sealing structs entire structs to encrypted blobs.

Sealing a struct results in an encrypted blob, and a content-encryption-key. The content-encryption-key must be provided again when unsealing the data. A content encryption key allows easy key-rotation of the encrypting-key, as now just the content-encryption-keys need to be re-uploaded, instead of all data.

The content-encryption-key cannot be re-used for encrypting other data.

Note: This is explicitly meant for structured data, not large binary blobs (files).

Implementations

Source

impl DataEnvelope

pub fn seal<Ids: KeySlotIds, T>( data: T, ctx: &mut KeyStoreContext<'_, Ids>, ) -> Result<(Self, Ids::Symmetric), DataEnvelopeError>

Seals a struct into an encrypted blob, and stores the content-encryption-key in the provided context.

pub fn seal_with_wrapping_key<Ids: KeySlotIds, T>( data: T, wrapping_key: &Ids::Symmetric, ctx: &mut KeyStoreContext<'_, Ids>, ) -> Result<(Self, EncString), DataEnvelopeError>

Seals a struct into an encrypted blob. The content encryption key is wrapped with the provided wrapping key

pub fn unseal<Ids: KeySlotIds, T>( &self, cek_keyslot: Ids::Symmetric, ctx: &mut KeyStoreContext<'_, Ids>, ) -> Result<T, DataEnvelopeError>

Unseals the data from the encrypted blob using a content-encryption-key stored in the context.

pub fn unseal_with_wrapping_key<Ids: KeySlotIds, T>( &self, wrapping_key: &Ids::Symmetric, wrapped_cek: &EncString, ctx: &mut KeyStoreContext<'_, Ids>, ) -> Result<T, DataEnvelopeError>

Unseals the data from the encrypted blob and wrapped content-encryption-key.