pub struct PasswordProtectedKeyEnvelope { /* private fields */ }Expand description
A password-protected key envelope can seal a symmetric key, and protect it with a password. It does so by using a Key Derivation Function (KDF), to increase the difficulty of brute-forcing the password.
The KDF parameters such as iterations and salt are stored in the envelope and do not have to be provided.
Internally, Argon2 is used as the KDF and XChaCha20-Poly1305 is used to encrypt the key.
Implementations
Sourceimpl PasswordProtectedKeyEnvelope
impl PasswordProtectedKeyEnvelope
Sourcepub fn seal<Ids: KeySlotIds>(
key_to_seal: Ids::Symmetric,
password: &str,
namespace: PasswordProtectedKeyEnvelopeNamespace,
ctx: &KeyStoreContext<'_, Ids>,
) -> Result<Self, PasswordProtectedKeyEnvelopeError>
pub fn seal<Ids: KeySlotIds>( key_to_seal: Ids::Symmetric, password: &str, namespace: PasswordProtectedKeyEnvelopeNamespace, ctx: &KeyStoreContext<'_, Ids>, ) -> Result<Self, PasswordProtectedKeyEnvelopeError>
Seals a symmetric key with a password, using the current default KDF parameters and a random salt.
This should never fail, except for memory allocation error, when running the KDF.
Sourcepub fn unseal<Ids: KeySlotIds>(
&self,
password: &str,
namespace: PasswordProtectedKeyEnvelopeNamespace,
ctx: &mut KeyStoreContext<'_, Ids>,
) -> Result<Ids::Symmetric, PasswordProtectedKeyEnvelopeError>
pub fn unseal<Ids: KeySlotIds>( &self, password: &str, namespace: PasswordProtectedKeyEnvelopeNamespace, ctx: &mut KeyStoreContext<'_, Ids>, ) -> Result<Ids::Symmetric, PasswordProtectedKeyEnvelopeError>
Unseals a symmetric key from the password-protected envelope, and stores it in the key store context.
Sourcepub fn reseal(
&self,
password: &str,
new_password: &str,
namespace: PasswordProtectedKeyEnvelopeNamespace,
) -> Result<Self, PasswordProtectedKeyEnvelopeError>
pub fn reseal( &self, password: &str, new_password: &str, namespace: PasswordProtectedKeyEnvelopeNamespace, ) -> Result<Self, PasswordProtectedKeyEnvelopeError>
Re-seals the key with new KDF parameters (updated settings, salt), and a new password
Sourcepub fn contained_key_id(
&self,
) -> Result<Option<KeyId>, PasswordProtectedKeyEnvelopeError>
pub fn contained_key_id( &self, ) -> Result<Option<KeyId>, PasswordProtectedKeyEnvelopeError>
Get the key ID of the contained key, if the key ID is stored on the envelope headers. Only COSE keys have a key ID, legacy keys do not.